import React from 'react';
import { Link } from 'react-router-dom';
import useBool from '@/utils/hooks/useBool';
import { Table, Space, Button, Row, Col, Card } from 'antd';
import { getTaCheckItem } from '@/service/tacheckitem';
import QuList from './QuList';
import LocForm from './LocForm';
import styles from './style.module.less';

export default (props) => {
  const { checkId } = props;

  const [list, setList] = React.useState([]);
  const [curItem, setCurItem] = React.useState();
  const [loading, startLoading, stopLoading] = useBool();
  const [open, setOpen] = React.useState(false);

  const onEdit = (row) => {
    // console.log('________________________>', row);
    setCurItem(row);
    setOpen(true);
  }



  const columns = [
    {
      title: '点位名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '分值',
      dataIndex: 'fullScore',
    },
    {
      title: '已收/计划数',
      dataIndex: 'num',
      key: 'num',
      render: (_, row) => {
        return (
          <Space>
            <span>
              <Link to={`/checkAnswer/loc?checkId=${row.checkId}&typeId=${row.typeId}&back=true`}>{row.answerNum || 0}</Link>
            </span>
            <span>/</span>
            <span>{row.num || 0}</span>
          </Space>
        )
      }
    },
    {
      title: '小计',
      dataIndex: 'fullScore',
      key: 'fullScore',
      render: (_, row) => row.fullScore ? Number(row.fullScore * (row.num || 1)).toFixed(2) : '-',
    },
    {
      title: '测评得分',
      dataIndex: 'score',
      key: 'score',
    },
    {
      title: '操作',
      key: 'options',
      width: 100,
      render: (_, row) => {
        return (
          <Space>
            <Button type="link" onClick={() => onEdit(row)}>编辑</Button>
          </Space>
        )
      }
    },
  ]

  const onChange = (item) => {
    const newList = list.map(x => x.itemId === item.itemId ? item : x);
    setList(newList);
  }

  const getRowClassName = (row) => {
    return [
      styles['yz-table-row'],
      (row.itemId == curItem?.itemId) ? styles.active : false,
    ].filter(Boolean).join(' ');
  }

  React.useEffect(() => {
    if (checkId) {
      startLoading();
      getTaCheckItem({ pageSize: 500, checkId, itemType: "loc" }).then(res => {
        setList(res.records || []);
        stopLoading();
      }).catch(() => {
        stopLoading();
      });
    }
  }, [checkId]);

  // console.log('---------------------------------------------------------->', list?.map((x) => Number(x.fullScore / (x.num || 1)).toFixed(2)))

  return (
    <Row gutter={24}>
      <Col span={12}>
        <Card>
          <Table
            sticky
            summary={() => (
              <Table.Summary>
                <Table.Summary.Row style={{ fontWeight: 'bolder' }}>
                  <Table.Summary.Cell index={0}>合计</Table.Summary.Cell>
                  <Table.Summary.Cell index={1}>{list?.map((x) => x.fullScore).reduce((total, num) => total + num, 0)}</Table.Summary.Cell>
                  <Table.Summary.Cell index={2}>
                    {list?.map((x) => x.answerNum).reduce((total, num) => total + num, 0)} / {list?.map((x) => x.num).reduce((total, num) => total + num, 0)}
                  </Table.Summary.Cell>
                  <Table.Summary.Cell index={3}>{list?.map((x) => Number(x.fullScore * (x.num || 1))).reduce((total, num) => total + num, 0).toFixed(2)}</Table.Summary.Cell>
                  <Table.Summary.Cell index={4}>{list?.map((x) => x.score).reduce((total, num) => total + num, 0)}</Table.Summary.Cell>
                </Table.Summary.Row>
              </Table.Summary>
            )}
            rowKey="typeId"
            loading={loading}
            columns={columns}
            dataSource={list}
            pagination={false}
            rowClassName={getRowClassName}
            onRow={(row) => ({
              onClick: () => setCurItem(row),
            })}
          />
          <LocForm
            checkId={checkId}
            itemId={curItem?.itemId}
            open={open}
            checkItem={curItem}
            onOpenChange={setOpen}
            onChange={onChange}
          />
        </Card>
      </Col>
      <Col span={12}>
        <QuList itemId={curItem?.itemId} />
      </Col>
    </Row>
  )
}
